feature_extraction
==================

.. automodule:: tsfel.feature_extraction
    :members:
    :undoc-members:
    :show-inheritance:

calc_features
-------------

.. automodule:: tsfel.feature_extraction.calc_features
    :members:
    :undoc-members:
    :show-inheritance:

features
--------

.. automodule:: tsfel.feature_extraction.features
    :members:
    :undoc-members:
    :show-inheritance:

feature_settings
----------------

.. automodule:: tsfel.feature_extraction.features_settings
    :members:
    :undoc-members:
    :show-inheritance:

feature_utils
-------------

.. automodule:: tsfel.feature_extraction.features_utils
    :members:
    :undoc-members:
    :show-inheritance:
